==> maverik-5.4.tar.gz: maverik-5.4/src/kernel/mav_class.c <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2000 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/


#include "mavlib_kernel.h"
#include <stdlib.h>
#include <stdio.h>

/* Routines to define and set a object classes */

MAV_class *mav_classNew(void)
{
  MAV_class *c= (MAV_class *) mav_malloc(sizeof(MAV_class));
  int i,j;
  
  for (i=0; i<MAV_MAX_CBS; i++) {
    for (j=0; j<MAV_MAX_WIN; j++) {
      c->fn[i][j]= NULL;
    }
  }

  return c;
}

MAV_SMSClass *mav_SMSClassNew(void)
{
  MAV_SMSClass *c= (MAV_SMSClass *) mav_malloc(sizeof(MAV_SMSClass));
  int i;

  for (i=0; i<MAV_MAX_CBS; i++) {
    c->fn[i]= NULL;
  }

  return c;
}

==> maverik-6.1.tar.gz: maverik-6.1/src/kernel/mav_class.c <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2001 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/


#include "mavlib_kernel.h"
#include <stdlib.h>
#include <stdio.h>

/* Routines to define and set a object classes */

MAV_class *mav_classNew(void)
{
  MAV_class *c= (MAV_class *) mav_malloc(sizeof(MAV_class));
  int i,j;
  
  for (i=0; i<MAV_MAX_CBS; i++) {
    for (j=0; j<MAV_MAX_WIN; j++) {
      c->fn[i][j]= NULL;
    }
  }

  return c;
}

MAV_SMSClass *mav_SMSClassNew(void)
{
  MAV_SMSClass *c= (MAV_SMSClass *) mav_malloc(sizeof(MAV_SMSClass));
  int i;

  for (i=0; i<MAV_MAX_CBS; i++) {
    c->fn[i]= NULL;
  }

  return c;
}
